# Just an example of setting the env variables required to use this package.

GPT_PROBE_0 = 'sk-ekOvFjAHKETQ9NOTAREALKEYSDNXwE3jyy7IHKA4s'
GPT_PROBE_1 = 'sk-X0hK82TSSbananasinpijamasarerunning downz1gpT3'
GPT_PROBE_2 = 'sk-24W74IputyourkeyshereobviouslyQyQFdt2ymTewRc'
import os

os.environ['OPEN_AI_KEY_0'] = GPT_PROBE_0
os.environ['OPEN_AI_KEY_1'] = GPT_PROBE_1
os.environ['OPEN_AI_KEY_2'] = GPT_PROBE_2

NOTHING ='nothing'
